==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d2/d11/station__func_8h.js <==
var station__func_8h =
[
    [ "AirportMaintenanceCost", "d2/d11/station__func_8h.html#a6f1a258c0bca3bd259ff1ea2fed08375", null ],
    [ "CanStationTileHavePylons", "d2/d11/station__func_8h.html#a68f4402719cbdf577d10a43c77317856", null ],
    [ "CanStationTileHaveWires", "d2/d11/station__func_8h.html#a1372f3a2354754d2cc522aee0cc0eb55", null ],
    [ "DeleteOilRig", "d2/d11/station__func_8h.html#ac48311aeac80dbe68d5635ebeecc486b", null ],
    [ "FindStationsAroundTiles", "d2/d11/station__func_8h.html#abda13909b93a9197e0935eba6c3d140e", null ],
    [ "GetAcceptanceAroundTiles", "d2/d11/station__func_8h.html#a4cee85b2187a73fe972877f84c9c0187", null ],
    [ "GetProductionAroundTiles", "d2/d11/station__func_8h.html#ad04c576d01a401f23528591f55ad8fb2", null ],
    [ "GetStationTileLayout", "d2/d11/station__func_8h.html#ac5ffef60476e49d0fecbedf84d7b290a", null ],
    [ "HasStationInUse", "d2/d11/station__func_8h.html#a67dad88b36405182dbcd12ace70595ed", null ],
    [ "IncreaseStats", "d2/d11/station__func_8h.html#ada054512693ccb59442b04296fc42d18", null ],
    [ "IncreaseStats", "d2/d11/station__func_8h.html#a2490e0ecc928638b4b14524ed6502dc8", null ],
    [ "IsStationTileBlocked", "d2/d11/station__func_8h.html#a96d4e85eca1515860b06b5c20c348815", null ],
    [ "ModifyStationRatingAround", "d2/d11/station__func_8h.html#aaa98fd6b53ded781d1cc6719f916e2e0", null ],
    [ "RerouteCargo", "d2/d11/station__func_8h.html#a3c24de6e78944614b187eb05be613289", null ],
    [ "ShowStationViewWindow", "d2/d11/station__func_8h.html#a84100f3615ce31e737c6e6a7e238fdfb", null ],
    [ "SplitGroundSpriteForOverlay", "d2/d11/station__func_8h.html#ad96c41b272c16d49cfff12c3efb3ed59", null ],
    [ "StationMaintenanceCost", "d2/d11/station__func_8h.html#a47b7d2869b40dfe0ff8b55558492b368", null ],
    [ "StationPickerDrawSprite", "d2/d11/station__func_8h.html#a4d8d3a2293cb590f3fc0b6ca09d8fb2a", null ],
    [ "UpdateAirportsNoise", "d2/d11/station__func_8h.html#aa3795816635adbdf6583319097119b77", null ],
    [ "UpdateAllStationVirtCoords", "d2/d11/station__func_8h.html#a8431113ce0a74baf67906ff027590737", null ],
    [ "UpdateStationAcceptance", "d2/d11/station__func_8h.html#aac6ae3d4f99dc215ddd9d2871e70d93a", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d2/d11/station__func_8h.js <==
var station__func_8h =
[
    [ "AirportMaintenanceCost", "d2/d11/station__func_8h.html#a6f1a258c0bca3bd259ff1ea2fed08375", null ],
    [ "CanStationTileHavePylons", "d2/d11/station__func_8h.html#a68f4402719cbdf577d10a43c77317856", null ],
    [ "CanStationTileHaveWires", "d2/d11/station__func_8h.html#a1372f3a2354754d2cc522aee0cc0eb55", null ],
    [ "ClearAllStationCachedNames", "d2/d11/station__func_8h.html#aeb662c9e06e23de519b2eba279753b0b", null ],
    [ "ClearDockingTilesCheckingNeighbours", "d2/d11/station__func_8h.html#a34902972a51e144f50f80854d9db0c4b", null ],
    [ "DeleteOilRig", "d2/d11/station__func_8h.html#ac48311aeac80dbe68d5635ebeecc486b", null ],
    [ "GetAcceptanceAroundTiles", "d2/d11/station__func_8h.html#a1c8362e39d32fe711e8fae86bdcfcb98", null ],
    [ "GetProductionAroundTiles", "d2/d11/station__func_8h.html#ad04c576d01a401f23528591f55ad8fb2", null ],
    [ "GetStationTileLayout", "d2/d11/station__func_8h.html#ac5ffef60476e49d0fecbedf84d7b290a", null ],
    [ "HasStationInUse", "d2/d11/station__func_8h.html#a67dad88b36405182dbcd12ace70595ed", null ],
    [ "IncreaseStats", "d2/d11/station__func_8h.html#a2490e0ecc928638b4b14524ed6502dc8", null ],
    [ "IncreaseStats", "d2/d11/station__func_8h.html#ada054512693ccb59442b04296fc42d18", null ],
    [ "IsStationTileBlocked", "d2/d11/station__func_8h.html#a96d4e85eca1515860b06b5c20c348815", null ],
    [ "IsValidDockingDirectionForDock", "d2/d11/station__func_8h.html#a03622130d5be1bd36cebbc93ff6c01af", null ],
    [ "ModifyStationRatingAround", "d2/d11/station__func_8h.html#aaa98fd6b53ded781d1cc6719f916e2e0", null ],
    [ "RemoveDockingTile", "d2/d11/station__func_8h.html#a4d8cc75de8f7fa9376bfff092792ecf5", null ],
    [ "RerouteCargo", "d2/d11/station__func_8h.html#a3c24de6e78944614b187eb05be613289", null ],
    [ "ShowStationViewWindow", "d2/d11/station__func_8h.html#a84100f3615ce31e737c6e6a7e238fdfb", null ],
    [ "SplitGroundSpriteForOverlay", "d2/d11/station__func_8h.html#ad96c41b272c16d49cfff12c3efb3ed59", null ],
    [ "StationMaintenanceCost", "d2/d11/station__func_8h.html#a47b7d2869b40dfe0ff8b55558492b368", null ],
    [ "StationPickerDrawSprite", "d2/d11/station__func_8h.html#a4d8d3a2293cb590f3fc0b6ca09d8fb2a", null ],
    [ "UpdateAirportsNoise", "d2/d11/station__func_8h.html#aa3795816635adbdf6583319097119b77", null ],
    [ "UpdateAllStationVirtCoords", "d2/d11/station__func_8h.html#a8431113ce0a74baf67906ff027590737", null ],
    [ "UpdateStationAcceptance", "d2/d11/station__func_8h.html#aac6ae3d4f99dc215ddd9d2871e70d93a", null ],
    [ "UpdateStationDockingTiles", "d2/d11/station__func_8h.html#ab90a520a24b7e505cce5af2141a83e9e", null ]
];
